package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.ConsultInfo;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.mapper.ConsultInfoMapper;
import com.ruoyi.system.service.IConsultInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 咨询列Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-08-14
 */
@Service
public class ConsultInfoServiceImpl implements IConsultInfoService 
{
    @Autowired
    private ConsultInfoMapper consultInfoMapper;

    /**
     * 查询咨询列
     * 
     * @param id 咨询列主键
     * @return 咨询列
     */
    @Override
    public ConsultInfo selectConsultInfoById(String id)
    {
        return consultInfoMapper.selectConsultInfoById(id);
    }

    /**
     * 查询咨询列列表
     * 
     * @param consultInfo 咨询列
     * @return 咨询列
     */
    @Override
    public List<ConsultInfo> selectConsultInfoList(ConsultInfo consultInfo)
    {
        return consultInfoMapper.selectConsultInfoList(consultInfo);
    }

    /**
     * 新增咨询列
     * 
     * @param consultInfo 咨询列
     * @return 结果
     */
    @Override
    public int insertConsultInfo(ConsultInfo consultInfo)
    {
        consultInfo.setCreateTime(DateUtils.getNowDate());
        return consultInfoMapper.insertConsultInfo(consultInfo);
    }

    /**
     * 修改咨询列
     * 
     * @param consultInfo 咨询列
     * @return 结果
     */
    @Override
    public int updateConsultInfo(ConsultInfo consultInfo)
    {
        consultInfo.setUpdateTime(DateUtils.getNowDate());
        return consultInfoMapper.updateConsultInfo(consultInfo);
    }

    /**
     * 批量删除咨询列
     * 
     * @param ids 需要删除的咨询列主键
     * @return 结果
     */
    @Override
    public int deleteConsultInfoByIds(String[] ids)
    {
        return consultInfoMapper.deleteConsultInfoByIds(ids);
    }

    /**
     * 删除咨询列信息
     * 
     * @param id 咨询列主键
     * @return 结果
     */
    @Override
    public int deleteConsultInfoById(String id)
    {
        return consultInfoMapper.deleteConsultInfoById(id);
    }
}
